bayespy.inference.vmp.nodes.deterministic.Deterministic.set_plotter
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.set_plotter